==> react-bootstrap-0.2.0.tgz: package/es/components/Button/index.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import cn from 'classnames';

import Group from './Group';

import buttonColors from '../../utils/buttonColors';
import sizes from '../../utils/sizes';

var Button = (_temp = _class = function (_Component) {
  _inherits(Button, _Component);

  function Button() {
    _classCallCheck(this, Button);

    return _possibleConstructorReturn(this, _Component.apply(this, arguments));
  }

  Button.prototype.render = function render() {
    var _props = this.props,
        tag = _props.tag,
        type = _props.type,
        active = _props.active,
        outline = _props.outline,
        color = _props.color,
        size = _props.size,
        className = _props.className,
        innerRef = _props.innerRef,
        children = _props.children,
        props = _objectWithoutProperties(_props, ['tag', 'type', 'active', 'outline', 'color', 'size', 'className', 'innerRef', 'children']);

    var Tag = props.href && tag === 'button' ? 'a' : tag;

    var classNames = cn('btn', 'btn-' + size, 'btn' + (outline ? '-outline' : '') + '-' + color, { active: active, disabled: props.disabled }, className);

    return React.createElement(
      Tag,
      _extends({}, props, {
        type: Tag === 'button' ? type : undefined,
        ref: typeof innerRef === 'function' ? innerRef : undefined,
        className: classNames
      }),
      children
    );
  };

  return Button;
}(Component), _class.defaultProps = {
  tag: 'button',
  type: 'button',
  active: false,
  outline: false,
  color: 'primary',
  size: 'md',
  className: '',
  innerRef: null,
  children: null
}, _class.Group = Group, _temp);
Button.propTypes = process.env.NODE_ENV !== "production" ? {
  tag: PropTypes.oneOfType([PropTypes.func, PropTypes.string]),
  type: PropTypes.string,
  active: PropTypes.bool,
  outline: PropTypes.bool,
  color: PropTypes.oneOf(buttonColors),
  size: PropTypes.oneOf(sizes),
  className: PropTypes.string,
  innerRef: PropTypes.func,
  children: PropTypes.node
} : {};


export default Button;

==> react-bootstrap-0.3.0.tgz: package/es/components/Button/index.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import cn from 'classnames';

import buttonColors from '../../utils/buttonColors';
import createComponent from '../../utils/createComponent';
import sizes from '../../utils/sizes';

var Group = createComponent('Button.Group', 'btn-group');

var Button = (_temp = _class = function (_Component) {
  _inherits(Button, _Component);

  function Button() {
    _classCallCheck(this, Button);

    return _possibleConstructorReturn(this, _Component.apply(this, arguments));
  }

  Button.prototype.render = function render() {
    var _props = this.props,
        tag = _props.tag,
        type = _props.type,
        active = _props.active,
        outline = _props.outline,
        color = _props.color,
        size = _props.size,
        innerRef = _props.innerRef,
        props = _objectWithoutProperties(_props, ['tag', 'type', 'active', 'outline', 'color', 'size', 'innerRef']);

    var Tag = props.href && tag === 'button' ? 'a' : tag;

    var className = cn('btn', 'btn-' + size, 'btn' + (outline ? '-outline' : '') + '-' + color, { active: active, disabled: props.disabled }, props.className);

    return React.createElement(Tag, _extends({}, props, {
      type: Tag === 'button' ? type : undefined,
      ref: typeof innerRef === 'function' ? innerRef : undefined,
      className: className
    }));
  };

  return Button;
}(Component), _class.defaultProps = {
  tag: 'button',
  type: 'button',
  active: false,
  outline: false,
  color: 'primary',
  size: 'md',
  innerRef: null
}, _class.Group = Group, _temp);
Button.propTypes = process.env.NODE_ENV !== "production" ? {
  tag: PropTypes.oneOfType([PropTypes.func, PropTypes.string]),
  type: PropTypes.string,
  active: PropTypes.bool,
  outline: PropTypes.bool,
  color: PropTypes.oneOf(buttonColors),
  size: PropTypes.oneOf(sizes),
  innerRef: PropTypes.func
} : {};


export default Button;
